@@ -18,3 +18,12 @@ cd -
 
 # Install java library
 ant install
+
+# Install container side scripts
+SRC=bin
+DST=/usr/local/libexec/storlets
+mkdir -p $DST
+chmod 755 $DST
+cp "$SRC/init_container.sh" $DST
+cp "$SRC/storlets-daemon" $DST
+cp "$SRC/storlets-daemon-factory" $DST
